@@ -13,7 +13,10 @@ def migrate(db):
         if name not in already_applied:
             fn(db)
             db["_llm_migrations"].insert(
-                {"name": name, "applied_at": str(datetime.datetime.utcnow())}
+                {
+                    "name": name,
+                    "applied_at": str(datetime.datetime.now(datetime.timezone.utc)),
+                }
             )
             already_applied.add(name)
 
@@ -227,3 +230,10 @@ def m012_attachments_tables(db):
         ),
         pk=("response_id", "attachment_id"),
     )
+
+
+@migration
+def m013_usage(db):
+    db["responses"].add_column("input_tokens", int)
+    db["responses"].add_column("output_tokens", int)
+    db["responses"].add_column("token_details", str)
