@@ -385,7 +385,7 @@ class Response(_BaseResponse):
 
     def __iter__(self) -> Iterator[str]:
         self._start = time.monotonic()
-        self._start_utcnow = datetime.datetime.utcnow()
+        self._start_utcnow = datetime.datetime.now(datetime.timezone.utc)
         if self._done:
             yield from self._chunks
             return
@@ -434,7 +434,7 @@ class AsyncResponse(_BaseResponse):
 
     def __aiter__(self):
         self._start = time.monotonic()
-        self._start_utcnow = datetime.datetime.utcnow()
+        self._start_utcnow = datetime.datetime.now(datetime.timezone.utc)
         return self
 
     async def __anext__(self) -> str:
@@ -757,6 +757,16 @@ class ModelWithAliases:
     async_model: AsyncModel
     aliases: Set[str]
 
+    def matches(self, query: str) -> bool:
+        query = query.lower()
+        all_strings: List[str] = []
+        all_strings.extend(self.aliases)
+        if self.model:
+            all_strings.append(str(self.model))
+        if self.async_model:
+            all_strings.append(str(self.async_model.model_id))
+        return any(query in alias.lower() for alias in all_strings)
+
 
 @dataclass
 class EmbeddingModelWithAliases:
