@@ -9,8 +9,9 @@ class Template(BaseModel):
     system: Optional[str] = None
     model: Optional[str] = None
     defaults: Optional[Dict[str, Any]] = None
-    # Should first fenced code block be extracted?
+    # Should a fenced code block be extracted?
     extract: Optional[bool] = None
+    extract_last: Optional[bool] = None
 
     class Config:
         extra = "forbid"
